@@ -1,4 +1,4 @@
-package plenigo::access::ProductsManager;
+package plenigo::ProductsManager;
 
 =head1 NAME
 
@@ -33,7 +33,7 @@ use Carp::Always;
 use plenigo::Ex;
 use plenigo::RestClient;
 
-our $VERSION = '2.0001';
+our $VERSION = '2.0002';
 
 has configuration => (
     is       => 'ro',
